/*
 * Copyright (C) 2023  Valentin Lorentz
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

use super::Component;
use color_eyre::eyre::{Result, WrapErr};
use ratatui::{prelude::*, widgets::*};

#[derive(Default)]
pub struct Backlog {}

impl Component for Backlog {
  fn draw(
    &mut self,
    frame: &mut Frame<'_>,
    area: Rect,
    buffers: &crate::buffers::Buffers,
  ) -> Result<()> {
    frame.render_widget(
      Paragraph::new(buffers.active_buffer().content())
        .block(Block::new().borders(Borders::ALL))
        .wrap(Wrap { trim: true }),
      area,
    );
    Ok(())
  }
}
